package com.sun.corba.se.impl.protocol;

import com.sun.corba.se.spi.ior.IOR;
import com.sun.corba.se.spi.ior.ObjectKey;
import java.util.Iterator;
import java.util.Set;
import org.omg.CORBA.SystemException;
import com.sun.corba.se.impl.encoding.MarshalOutputStream;
import com.sun.corba.se.impl.encoding.MarshalInputStream;
import com.sun.corba.se.spi.protocol.CorbaMessageMediator;
import com.sun.corba.se.pept.protocol.MessageMediator;
import com.sun.corba.se.impl.logging.ORBUtilSystemException;
import com.sun.corba.se.spi.orb.ORB;
import com.sun.corba.se.spi.protocol.CorbaServerRequestDispatcher;

public class BootstrapServerRequestDispatcher implements CorbaServerRequestDispatcher
{
    private ORB orb;
    ORBUtilSystemException wrapper;
    private static final boolean debug = false;
    
    public BootstrapServerRequestDispatcher(ORB orb) {
        this.orb = orb;
        this.wrapper = ORBUtilSystemException.get(orb, "rpc.protocol");
    }
    
    public void dispatch(MessageMediator messageMediator) {
        CorbaMessageMediator corbaMessageMediator = (CorbaMessageMediator)messageMediator;
        try {
            MarshalInputStream marshalInputStream = (MarshalInputStream)corbaMessageMediator.getInputObject();
            String operationName = corbaMessageMediator.getOperationName();
            MarshalOutputStream marshalOutputStream = (MarshalOutputStream)corbaMessageMediator.getProtocolHandler().createResponse(corbaMessageMediator, null).getOutputObject();
            if (operationName.equals("get")) {
                marshalOutputStream.write_Object(this.orb.getLocalResolver().resolve(marshalInputStream.read_string()));
            }
            else if (operationName.equals("list")) {
                Set<Object> list = this.orb.getLocalResolver().list();
                marshalOutputStream.write_long(list.size());
                Iterator<Object> iterator = list.iterator();
                while (iterator.hasNext()) {
                    marshalOutputStream.write_string((String)iterator.next());
                }
            }
            else {
                throw this.wrapper.illegalBootstrapOperation(operationName);
            }
        }
        catch (SystemException ex) {
            corbaMessageMediator.getProtocolHandler().createSystemExceptionResponse(corbaMessageMediator, ex, null);
        }
        catch (RuntimeException ex2) {
            corbaMessageMediator.getProtocolHandler().createSystemExceptionResponse(corbaMessageMediator, this.wrapper.bootstrapRuntimeException(ex2), null);
        }
        catch (Exception ex3) {
            corbaMessageMediator.getProtocolHandler().createSystemExceptionResponse(corbaMessageMediator, this.wrapper.bootstrapException(ex3), null);
        }
    }
    
    public IOR locate(ObjectKey objectKey) {
        return null;
    }
    
    public int getId() {
        throw this.wrapper.genericNoImpl();
    }
}
